"""Config for pysma documentation."""

project = "PySMA"
copyright = "2021, Johann Kellerman, René Klomp"  # noqa: A001
author = "Johann Kellerman, René Klomp"

extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.napoleon",
]

autoclass_content = "both"
html_theme = "sphinx_rtd_theme"
